#!/bin/bash
clear
echo "ARM x-Platform dev. environment for fbvncserver ..."
export PROJECT_HOME="/home/oe/fbvncserver"
export KERNEL_PATH="${PROJECT_HOME}/K2-4-19-rmk6-pxa1-hh41/linux/kernel/"
export SRC_ROOT="${PROJECT_HOME}/core/src"
export PROJECT_BIN="${PROJECT_HOME}/core/bin"

gcc_version="3.3.2"
export COMPILER_PATH="/usr/local/arm/${gcc_version}"
libpath="${PROJECT_HOME}/core/bin-lib"
export LIBPATH=${libpath}
export CFLAGS="${CFLAGS} -I ${libpath}"
export CPPFLAGS="${CPPFLAGS} -I ${libpath}"  # additional header [.h] file
echo
if [ -e "${SRC_ROOT}" ]
  then echo " [OK]: /core/src"
  else echo "  [F]: /core/src"
fi
if [ -e "${PROJECT_BIN}" ]
then echo " [OK]: /core/bin"
else
  echo " [Warning]: /core/bin NOT found ... "
  if (mkdir "${PROJECT_BIN}")
    then echo " -> created."
    else echo " [F]: & Im not able to create the directory."
  fi
fi
echo "libs (.h)"
if [ -e "${libpath}/zconf.h" ]
  then echo " [OK]: zconf.h"
  else echo " [Warning]: zconf.h"
fi
if [ -e "${libpath}/zlib.h" ]
  then echo " [OK]: zlib.h"
  else echo " [Warning]: zlib.h"
fi
if [ -e "${libpath}/jconfig.h" ]
  then echo " [OK]: jconfig.h"
  else echo " [Warning]: jconfig.h"
fi
if [ -e "${libpath}/jmorecfg.h" ]
  then echo " [OK]: jmorecfg.h"
  else echo " [Warning]: jmorecfg.h"
fi
if [ -e "${libpath}/jpeglib.h" ]
  then echo " [OK]: jpeglib.h"
  else echo " [Warning]: jpeglib.h"
fi
if [ -e "${libpath}/jerror.h" ]
  then echo " [OK]: jerror.h"
  else echo " [Warning]: jerror.h"
fi
if [ -e "${libpath}/rfb/rfb.h" ]
  then echo " [OK]: /rfb/rfb.h"
  else echo " [Warning]: /rfb/rfb.h"
fi
if [ -e "${libpath}/rfb/keysym.h" ]
  then echo " [OK]: /rfb/keysym.h"
  else echo " [Warning]: /rfb/keysym.h"
fi
if [ -e "${libpath}/rfb/rfbproto.h" ]
  then echo " [OK]: /rfb/rfbproto.h"
  else echo " [Warning]: /rfb/rfbproto.h"
fi
if [ -e "${libpath}/rfb/rfbconfig.h" ]
  then echo " [OK]: /rfb/rfbconfig.h"
  else echo " [Warning]: /rfb/rfbconfig.h"
fi
if [ -e "${libpath}/rfb/rfbint.h" ]
  then echo " [OK]: /rfb/rfbint.h"
  else echo " [Warning]: /rfb/rfbint.h"
fi
echo "libs (static bin)"
if [ -e "${libpath}/libz.a" ]
  then echo " [OK]: libz.a"
  else echo " [Warning]: libz.a"
fi
if [ -e "${libpath}/libjpeg.a" ]
  then echo " [OK]: libjpeg.a"
  else echo " [Warning]: libjpeg.a"
fi
if [ -e "${libpath}/libvncserver.a" ]
  then echo " [OK]: libvncserver.a"
  else echo " [Warning]: libvncserver.a"
fi
echo "kernel"
if [ -e "${KERNEL_PATH}" ]
  then
  if [ -e "${KERNEL_PATH}/include/linux/autoconf.h" ]
      then echo " [OK]: autoconf.h"
      else echo " [Warning]: autoconf.h "
    fi
      if [ -e "${KERNEL_PATH}/include/linux/version.h" ]
      then
        echo " [OK]: version.h "
        Version=`cat ${KERNEL_PATH}/include/linux/version.h | grep UTS_RELEASE`
        Version=${Version##*UTS_RELEASE }
        Version=${Version//'"'/''}
        export KERNEL_VERSION=${Version}
        echo "       ${KERNEL_VERSION}"

        if [ -d "${PROJECT_BIN}/modules/${KERNEL_VERSION}" ]
         then echo " [OK]: kbd-module target directory present "
         else
           echo " [WARNING]: kbd-module target directory missing => I'll create it ... "
           mkdir "${PROJECT_BIN}/modules/${KERNEL_VERSION}"
        fi

      else echo " [Warning]: version.h"
    fi
else echo " [Warning]: /ipkg/kernel"
fi
echo "x-compiler"
if [ -e "${COMPILER_PATH}" ]
  then
    echo " [OK]: ARM x-compiler ${gcc_version}"
    export PATH="${COMPILER_PATH}/bin:${PATH}"
  else
    echo " [F]: ARM x-compiler ${gcc_version}"
    echo "  |---> ftp://ftp.handhelds.org/projects/toolchain/ "
   gcc_version="[not found] "
fi
CC=arm-linux-gcc
CXX=arm-linux-g++
CCX=arm-linux-gcc
CXXX=arm-linux-g++
COMPILER=arm-linux-gcc
LINKER=arm-linux-ld
LD=${LINKER}
STRIP_PROG=$COMPILER_PATH/bin/strip
PREPROCESSCMD="$COMPILER -E"
export STRIP_PROG COMPILER LINKER LD PREPROCESSCMD CC CXX CCX CXXX

PS1="\nARM Cross-Compiler ${gcc_version} @ \w/ \n => "
export PS1
cd "${SRC_ROOT}"
/bin/bash --norc
