#ifndef ROTATE_H
#define ROTATE_H
/**
 * @file	rotate.h
 * @brief	Utility function(s) to rotate & flip screen buffers
 * 
 * supported C-PreProcessor directives
 * - DEBUG
 * 
 * @author	
 * - Patrik Gfeller
 * 
 * @date	2006
 */
/* 
 * Standard ANSI C 
 * Documentation @ http://www.cplusplus.com/ref/
 */
#include <stdlib.h> // general purpose (memory allocation, process control, conversion ...) 
#include <math.h>   // library for mathematic operations (linker static: -lm)               
/*
 * LibVNCServer 
 * URL: http://sourceforge.net/projects/libvncserver/
 */
#include "rfb/rfb.h"
#include "rfb/rfbregion.h"
/**
 * ... did the PDA screen change?
 * 
 * @param *fbbuf        pointer to mmap'ed framebuffer
 * @param *cmpbuf       pointer to a copy of the previous framebuffer contents
 * @param size          size
 * 
 * @return 0: the screen did NOT change, 1: the screen changed
 */
  unsigned short int notEqual ( unsigned short int *fbbuf, unsigned short int *cmpbuf, unsigned long  int  size);
/** 
 * ...reads the HW framebuffer with a 0 degree rotation. 
 * The result is stored in the remote-framebuffer structure. This function is
 * implemented for 0,90,180 and 270 degrees (rotate0, rotate90, rotate180 & rotate270)
 * 
 * @param rfbScreen pointer to a rfbScreenInfoPtr structur as defined in rfb.h (LibVNCServer).
 * @param fbbuf    pointer to a mem-mapped iPAQ framebuffer
 * @param cmpbuf   pointer to the compare buffer
 */  
 void rotate0   ( rfbScreenInfoPtr rfbScreen, unsigned short int* fbbuf, unsigned short int* cmpbuf );
 void rotate90  ( rfbScreenInfoPtr rfbScreen, unsigned short int* fbbuf, unsigned short int* cmpbuf );
 void rotate180 ( rfbScreenInfoPtr rfbScreen, unsigned short int* fbbuf, unsigned short int* cmpbuf );
 void rotate270 ( rfbScreenInfoPtr rfbScreen, unsigned short int* fbbuf, unsigned short int* cmpbuf );
#endif

